@@ -290,7 +290,7 @@ download_and_parse (GUPnPContext *context,
         SoupMessage *msg;
         int status;
 
-        session = _gupnp_context_get_session (context);
+        session = gupnp_context_get_session (context);
 
         msg = soup_message_new (SOUP_METHOD_GET, location);
         if (msg == NULL) {
@@ -469,6 +469,8 @@ gupnp_root_device_constructor (GType                  type,
                       "url-base", url_base,
                       NULL);
 
+	soup_uri_free (url_base);
+
         device->priv->own_description_doc = own_description_doc;
 
         /* Create resource group */
